# coding: utf-8

"""
    evaluation-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobCandidateStatusRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment': 'str',
        'current_status': 'str',
        'previous_status': 'str',
        'is_rejected': 'bool'
    }

    attribute_map = {
        'comment': 'comment',
        'current_status': 'currentStatus',
        'previous_status': 'previousStatus',
        'is_rejected': 'isRejected'
    }

    def __init__(self, comment=None, current_status=None, previous_status=None, is_rejected=None):  # noqa: E501
        """JobCandidateStatusRequest - a model defined in Swagger"""  # noqa: E501
        self._comment = None
        self._current_status = None
        self._previous_status = None
        self._is_rejected = None
        self.discriminator = None
        if comment is not None:
            self.comment = comment
        if current_status is not None:
            self.current_status = current_status
        if previous_status is not None:
            self.previous_status = previous_status
        if is_rejected is not None:
            self.is_rejected = is_rejected

    @property
    def comment(self):
        """Gets the comment of this JobCandidateStatusRequest.  # noqa: E501

        Comment added by user.  # noqa: E501

        :return: The comment of this JobCandidateStatusRequest.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this JobCandidateStatusRequest.

        Comment added by user.  # noqa: E501

        :param comment: The comment of this JobCandidateStatusRequest.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def current_status(self):
        """Gets the current_status of this JobCandidateStatusRequest.  # noqa: E501

        Current job candidacy status is based on the decision provided by the user.  # noqa: E501

        :return: The current_status of this JobCandidateStatusRequest.  # noqa: E501
        :rtype: str
        """
        return self._current_status

    @current_status.setter
    def current_status(self, current_status):
        """Sets the current_status of this JobCandidateStatusRequest.

        Current job candidacy status is based on the decision provided by the user.  # noqa: E501

        :param current_status: The current_status of this JobCandidateStatusRequest.  # noqa: E501
        :type: str
        """

        self._current_status = current_status

    @property
    def previous_status(self):
        """Gets the previous_status of this JobCandidateStatusRequest.  # noqa: E501

        Current status of the candidate to job before this decision.  # noqa: E501

        :return: The previous_status of this JobCandidateStatusRequest.  # noqa: E501
        :rtype: str
        """
        return self._previous_status

    @previous_status.setter
    def previous_status(self, previous_status):
        """Sets the previous_status of this JobCandidateStatusRequest.

        Current status of the candidate to job before this decision.  # noqa: E501

        :param previous_status: The previous_status of this JobCandidateStatusRequest.  # noqa: E501
        :type: str
        """

        self._previous_status = previous_status

    @property
    def is_rejected(self):
        """Gets the is_rejected of this JobCandidateStatusRequest.  # noqa: E501

        True or false whether the candidate is rejected.  # noqa: E501

        :return: The is_rejected of this JobCandidateStatusRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_rejected

    @is_rejected.setter
    def is_rejected(self, is_rejected):
        """Sets the is_rejected of this JobCandidateStatusRequest.

        True or false whether the candidate is rejected.  # noqa: E501

        :param is_rejected: The is_rejected of this JobCandidateStatusRequest.  # noqa: E501
        :type: bool
        """

        self._is_rejected = is_rejected

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobCandidateStatusRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobCandidateStatusRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ex-search-api

    These APIs helps in searching and providing suggestions based on keywords within employee profiles.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmployeeSearchRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'keyword': 'str',
        'common': 'CommonNode',
        '_from': 'int',
        'size': 'int',
        'filters': 'FiltersNode',
        'tab_info': 'TabInfoNode'
    }

    attribute_map = {
        'keyword': 'keyword',
        'common': 'common',
        '_from': 'from',
        'size': 'size',
        'filters': 'filters',
        'tab_info': 'tabInfo'
    }

    def __init__(self, keyword=None, common=None, _from=None, size=None, filters=None, tab_info=None):  # noqa: E501
        """EmployeeSearchRequest - a model defined in Swagger"""  # noqa: E501
        self._keyword = None
        self._common = None
        self.__from = None
        self._size = None
        self._filters = None
        self._tab_info = None
        self.discriminator = None
        if keyword is not None:
            self.keyword = keyword
        if common is not None:
            self.common = common
        if _from is not None:
            self._from = _from
        if size is not None:
            self.size = size
        if filters is not None:
            self.filters = filters
        if tab_info is not None:
            self.tab_info = tab_info

    @property
    def keyword(self):
        """Gets the keyword of this EmployeeSearchRequest.  # noqa: E501

        Keyword to search.  # noqa: E501

        :return: The keyword of this EmployeeSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._keyword

    @keyword.setter
    def keyword(self, keyword):
        """Sets the keyword of this EmployeeSearchRequest.

        Keyword to search.  # noqa: E501

        :param keyword: The keyword of this EmployeeSearchRequest.  # noqa: E501
        :type: str
        """

        self._keyword = keyword

    @property
    def common(self):
        """Gets the common of this EmployeeSearchRequest.  # noqa: E501


        :return: The common of this EmployeeSearchRequest.  # noqa: E501
        :rtype: CommonNode
        """
        return self._common

    @common.setter
    def common(self, common):
        """Sets the common of this EmployeeSearchRequest.


        :param common: The common of this EmployeeSearchRequest.  # noqa: E501
        :type: CommonNode
        """

        self._common = common

    @property
    def _from(self):
        """Gets the _from of this EmployeeSearchRequest.  # noqa: E501

        Starting point from which the data should be retrieved.  # noqa: E501

        :return: The _from of this EmployeeSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this EmployeeSearchRequest.

        Starting point from which the data should be retrieved.  # noqa: E501

        :param _from: The _from of this EmployeeSearchRequest.  # noqa: E501
        :type: int
        """

        self.__from = _from

    @property
    def size(self):
        """Gets the size of this EmployeeSearchRequest.  # noqa: E501

        Size of the response.  # noqa: E501

        :return: The size of this EmployeeSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this EmployeeSearchRequest.

        Size of the response.  # noqa: E501

        :param size: The size of this EmployeeSearchRequest.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def filters(self):
        """Gets the filters of this EmployeeSearchRequest.  # noqa: E501


        :return: The filters of this EmployeeSearchRequest.  # noqa: E501
        :rtype: FiltersNode
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this EmployeeSearchRequest.


        :param filters: The filters of this EmployeeSearchRequest.  # noqa: E501
        :type: FiltersNode
        """

        self._filters = filters

    @property
    def tab_info(self):
        """Gets the tab_info of this EmployeeSearchRequest.  # noqa: E501


        :return: The tab_info of this EmployeeSearchRequest.  # noqa: E501
        :rtype: TabInfoNode
        """
        return self._tab_info

    @tab_info.setter
    def tab_info(self, tab_info):
        """Sets the tab_info of this EmployeeSearchRequest.


        :param tab_info: The tab_info of this EmployeeSearchRequest.  # noqa: E501
        :type: TabInfoNode
        """

        self._tab_info = tab_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmployeeSearchRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmployeeSearchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    communications-sms

    These APIs ensures an easy integration process of SMS management for developers to send, read, and track SMS histories within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class SMSCommunicationsApi(object):
    base_path = "/communications/sms"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def fetchsms_communications(self, phone_number, x_ph_userid, **kwargs):  # noqa: E501
        """Get SMS History  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetchsms_communications(phone_number, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str phone_number: (required)
        :param str x_ph_userid: (required)
        :param int offset:
        :param int limit:
        :return: SMSHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.fetchsms_communications_with_http_info(phone_number, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.fetchsms_communications_with_http_info(phone_number, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def fetchsms_communications_with_http_info(self, phone_number, x_ph_userid, **kwargs):  # noqa: E501
        """Get SMS History  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetchsms_communications_with_http_info(phone_number, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str phone_number: (required)
        :param str x_ph_userid: (required)
        :param int offset:
        :param int limit:
        :return: SMSHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['phone_number', 'x_ph_userid', 'offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fetchsms_communications" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'phone_number' is set
        if ('phone_number' not in params or
                params['phone_number'] is None):
            raise ValueError("Missing the required parameter `phone_number` when calling `fetchsms_communications`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `fetchsms_communications`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'phone_number' in params:
            query_params.append(('phoneNumber', params['phone_number']))  # noqa: E501

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SMSHistory',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_opt_in(self, x_ph_userid, **kwargs):  # noqa: E501
        """Get OptIn Status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_opt_in(x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_userid: (required)
        :param str email:
        :param str phone_number:
        :return: OptInStatus
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_opt_in_with_http_info(x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_opt_in_with_http_info(x_ph_userid, **kwargs)  # noqa: E501
            return data

    def get_opt_in_with_http_info(self, x_ph_userid, **kwargs):  # noqa: E501
        """Get OptIn Status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_opt_in_with_http_info(x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_userid: (required)
        :param str email:
        :param str phone_number:
        :return: OptInStatus
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_ph_userid', 'email', 'phone_number']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_opt_in" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `get_opt_in`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'email' in params:
            query_params.append(('email', params['email']))  # noqa: E501
        if 'phone_number' in params:
            query_params.append(('phoneNumber', params['phone_number']))  # noqa: E501

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/optIn', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OptInStatus',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_opt_in_history(self, phone_number, x_ph_userid, **kwargs):  # noqa: E501
        """Get OptIn History  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_opt_in_history(phone_number, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str phone_number: (required)
        :param str x_ph_userid: (required)
        :param int offset:
        :param int size:
        :param str communication_id:
        :return: OptInHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_opt_in_history_with_http_info(phone_number, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_opt_in_history_with_http_info(phone_number, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def get_opt_in_history_with_http_info(self, phone_number, x_ph_userid, **kwargs):  # noqa: E501
        """Get OptIn History  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_opt_in_history_with_http_info(phone_number, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str phone_number: (required)
        :param str x_ph_userid: (required)
        :param int offset:
        :param int size:
        :param str communication_id:
        :return: OptInHistory
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['phone_number', 'x_ph_userid', 'offset', 'size', 'communication_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_opt_in_history" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'phone_number' is set
        if ('phone_number' not in params or
                params['phone_number'] is None):
            raise ValueError("Missing the required parameter `phone_number` when calling `get_opt_in_history`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `get_opt_in_history`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'size' in params:
            query_params.append(('size', params['size']))  # noqa: E501
        if 'communication_id' in params:
            query_params.append(('communicationId', params['communication_id']))  # noqa: E501
        if 'phone_number' in params:
            query_params.append(('phoneNumber', params['phone_number']))  # noqa: E501

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/optIn/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OptInHistory',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_sms(self, body, x_ph_userid, **kwargs):  # noqa: E501
        """Send SMS  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_sms(body, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SendSMSRequest body: (required)
        :param str x_ph_userid: (required)
        :return: SendSMS
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.send_sms_with_http_info(body, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.send_sms_with_http_info(body, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def send_sms_with_http_info(self, body, x_ph_userid, **kwargs):  # noqa: E501
        """Send SMS  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_sms_with_http_info(body, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SendSMSRequest body: (required)
        :param str x_ph_userid: (required)
        :return: SendSMS
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_userid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_sms" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `send_sms`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `send_sms`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/send', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SendSMS',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def sms_activity(self, activity_id, phone_number, x_ph_userid, **kwargs):  # noqa: E501
        """Get SMS Activity  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.sms_activity(activity_id, phone_number, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_id: (required)
        :param str phone_number: (required)
        :param str x_ph_userid: (required)
        :return: SMSActivity
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.sms_activity_with_http_info(activity_id, phone_number, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.sms_activity_with_http_info(activity_id, phone_number, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def sms_activity_with_http_info(self, activity_id, phone_number, x_ph_userid, **kwargs):  # noqa: E501
        """Get SMS Activity  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.sms_activity_with_http_info(activity_id, phone_number, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_id: (required)
        :param str phone_number: (required)
        :param str x_ph_userid: (required)
        :return: SMSActivity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_id', 'phone_number', 'x_ph_userid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sms_activity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_id' is set
        if ('activity_id' not in params or
                params['activity_id'] is None):
            raise ValueError("Missing the required parameter `activity_id` when calling `sms_activity`")  # noqa: E501
        # verify the required parameter 'phone_number' is set
        if ('phone_number' not in params or
                params['phone_number'] is None):
            raise ValueError("Missing the required parameter `phone_number` when calling `sms_activity`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `sms_activity`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'activity_id' in params:
            query_params.append(('activityId', params['activity_id']))  # noqa: E501
        if 'phone_number' in params:
            query_params.append(('phoneNumber', params['phone_number']))  # noqa: E501

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/activity', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SMSActivity',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_opt_in(self, body, x_ph_userid, **kwargs):  # noqa: E501
        """Update OptIn Status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_opt_in(body, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param OptInRequest body: (required)
        :param str x_ph_userid: (required)
        :return: OptInResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_opt_in_with_http_info(body, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.update_opt_in_with_http_info(body, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def update_opt_in_with_http_info(self, body, x_ph_userid, **kwargs):  # noqa: E501
        """Update OptIn Status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_opt_in_with_http_info(body, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param OptInRequest body: (required)
        :param str x_ph_userid: (required)
        :return: OptInResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_userid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_opt_in" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_opt_in`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `update_opt_in`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/optIn', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OptInResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    aisourcing-api

    AI matching FitScore provides a concise assessment indicating how well a candidate aligns with a job based on their skills, experience, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class FitscoreResponseResult(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_id': 'str',
        'fit_level': 'str',
        'title_fit': 'str',
        'skill_fit': 'str',
        'experience_fit': 'str',
        'location_fit': 'str',
        'skill_gap': 'FitscoreResponseSkillGap'
    }

    attribute_map = {
        'job_id': 'jobId',
        'fit_level': 'fitLevel',
        'title_fit': 'titleFit',
        'skill_fit': 'skillFit',
        'experience_fit': 'experienceFit',
        'location_fit': 'locationFit',
        'skill_gap': 'skillGap'
    }

    def __init__(self, job_id=None, fit_level=None, title_fit=None, skill_fit=None, experience_fit=None, location_fit=None, skill_gap=None):  # noqa: E501
        """FitscoreResponseResult - a model defined in Swagger"""  # noqa: E501
        self._job_id = None
        self._fit_level = None
        self._title_fit = None
        self._skill_fit = None
        self._experience_fit = None
        self._location_fit = None
        self._skill_gap = None
        self.discriminator = None
        if job_id is not None:
            self.job_id = job_id
        if fit_level is not None:
            self.fit_level = fit_level
        if title_fit is not None:
            self.title_fit = title_fit
        if skill_fit is not None:
            self.skill_fit = skill_fit
        if experience_fit is not None:
            self.experience_fit = experience_fit
        if location_fit is not None:
            self.location_fit = location_fit
        if skill_gap is not None:
            self.skill_gap = skill_gap

    @property
    def job_id(self):
        """Gets the job_id of this FitscoreResponseResult.  # noqa: E501

        Job Id for which fitscore is calculated.  # noqa: E501

        :return: The job_id of this FitscoreResponseResult.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this FitscoreResponseResult.

        Job Id for which fitscore is calculated.  # noqa: E501

        :param job_id: The job_id of this FitscoreResponseResult.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def fit_level(self):
        """Gets the fit_level of this FitscoreResponseResult.  # noqa: E501

        Shows how well the user fits the job.  # noqa: E501

        :return: The fit_level of this FitscoreResponseResult.  # noqa: E501
        :rtype: str
        """
        return self._fit_level

    @fit_level.setter
    def fit_level(self, fit_level):
        """Sets the fit_level of this FitscoreResponseResult.

        Shows how well the user fits the job.  # noqa: E501

        :param fit_level: The fit_level of this FitscoreResponseResult.  # noqa: E501
        :type: str
        """

        self._fit_level = fit_level

    @property
    def title_fit(self):
        """Gets the title_fit of this FitscoreResponseResult.  # noqa: E501

        Shows how well the user title fits the job.  # noqa: E501

        :return: The title_fit of this FitscoreResponseResult.  # noqa: E501
        :rtype: str
        """
        return self._title_fit

    @title_fit.setter
    def title_fit(self, title_fit):
        """Sets the title_fit of this FitscoreResponseResult.

        Shows how well the user title fits the job.  # noqa: E501

        :param title_fit: The title_fit of this FitscoreResponseResult.  # noqa: E501
        :type: str
        """

        self._title_fit = title_fit

    @property
    def skill_fit(self):
        """Gets the skill_fit of this FitscoreResponseResult.  # noqa: E501

        Shows how well the user skills fits the job.  # noqa: E501

        :return: The skill_fit of this FitscoreResponseResult.  # noqa: E501
        :rtype: str
        """
        return self._skill_fit

    @skill_fit.setter
    def skill_fit(self, skill_fit):
        """Sets the skill_fit of this FitscoreResponseResult.

        Shows how well the user skills fits the job.  # noqa: E501

        :param skill_fit: The skill_fit of this FitscoreResponseResult.  # noqa: E501
        :type: str
        """

        self._skill_fit = skill_fit

    @property
    def experience_fit(self):
        """Gets the experience_fit of this FitscoreResponseResult.  # noqa: E501

        Shows how well the user experience fits the job.  # noqa: E501

        :return: The experience_fit of this FitscoreResponseResult.  # noqa: E501
        :rtype: str
        """
        return self._experience_fit

    @experience_fit.setter
    def experience_fit(self, experience_fit):
        """Sets the experience_fit of this FitscoreResponseResult.

        Shows how well the user experience fits the job.  # noqa: E501

        :param experience_fit: The experience_fit of this FitscoreResponseResult.  # noqa: E501
        :type: str
        """

        self._experience_fit = experience_fit

    @property
    def location_fit(self):
        """Gets the location_fit of this FitscoreResponseResult.  # noqa: E501

        Shows how well the user location fits the job.  # noqa: E501

        :return: The location_fit of this FitscoreResponseResult.  # noqa: E501
        :rtype: str
        """
        return self._location_fit

    @location_fit.setter
    def location_fit(self, location_fit):
        """Sets the location_fit of this FitscoreResponseResult.

        Shows how well the user location fits the job.  # noqa: E501

        :param location_fit: The location_fit of this FitscoreResponseResult.  # noqa: E501
        :type: str
        """

        self._location_fit = location_fit

    @property
    def skill_gap(self):
        """Gets the skill_gap of this FitscoreResponseResult.  # noqa: E501


        :return: The skill_gap of this FitscoreResponseResult.  # noqa: E501
        :rtype: FitscoreResponseSkillGap
        """
        return self._skill_gap

    @skill_gap.setter
    def skill_gap(self, skill_gap):
        """Sets the skill_gap of this FitscoreResponseResult.


        :param skill_gap: The skill_gap of this FitscoreResponseResult.  # noqa: E501
        :type: FitscoreResponseSkillGap
        """

        self._skill_gap = skill_gap

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FitscoreResponseResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FitscoreResponseResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetCandidatesResponseDataHiringManagerReviewStatus(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reviewed_by_email': 'str',
        'crm_manager_approval': 'str',
        'reviewed_by_name': 'str',
        'current_status': 'str',
        'manager_approval': 'str',
        'latest_manager_comment': 'str',
        'comment': 'str',
        'updated_date': 'str',
        'previous_status': 'str',
        'interview_overall_avg_rating': 'str'
    }

    attribute_map = {
        'reviewed_by_email': 'reviewedByEmail',
        'crm_manager_approval': 'crmManagerApproval',
        'reviewed_by_name': 'reviewedByName',
        'current_status': 'currentStatus',
        'manager_approval': 'managerApproval',
        'latest_manager_comment': 'latestManagerComment',
        'comment': 'comment',
        'updated_date': 'updatedDate',
        'previous_status': 'previousStatus',
        'interview_overall_avg_rating': 'interviewOverallAvgRating'
    }

    def __init__(self, reviewed_by_email=None, crm_manager_approval=None, reviewed_by_name=None, current_status=None, manager_approval=None, latest_manager_comment=None, comment=None, updated_date=None, previous_status=None, interview_overall_avg_rating=None):  # noqa: E501
        """GetCandidatesResponseDataHiringManagerReviewStatus - a model defined in Swagger"""  # noqa: E501
        self._reviewed_by_email = None
        self._crm_manager_approval = None
        self._reviewed_by_name = None
        self._current_status = None
        self._manager_approval = None
        self._latest_manager_comment = None
        self._comment = None
        self._updated_date = None
        self._previous_status = None
        self._interview_overall_avg_rating = None
        self.discriminator = None
        if reviewed_by_email is not None:
            self.reviewed_by_email = reviewed_by_email
        if crm_manager_approval is not None:
            self.crm_manager_approval = crm_manager_approval
        if reviewed_by_name is not None:
            self.reviewed_by_name = reviewed_by_name
        if current_status is not None:
            self.current_status = current_status
        if manager_approval is not None:
            self.manager_approval = manager_approval
        if latest_manager_comment is not None:
            self.latest_manager_comment = latest_manager_comment
        if comment is not None:
            self.comment = comment
        if updated_date is not None:
            self.updated_date = updated_date
        if previous_status is not None:
            self.previous_status = previous_status
        if interview_overall_avg_rating is not None:
            self.interview_overall_avg_rating = interview_overall_avg_rating

    @property
    def reviewed_by_email(self):
        """Gets the reviewed_by_email of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501

        Email of the latest user who updated the review.  # noqa: E501

        :return: The reviewed_by_email of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :rtype: str
        """
        return self._reviewed_by_email

    @reviewed_by_email.setter
    def reviewed_by_email(self, reviewed_by_email):
        """Sets the reviewed_by_email of this GetCandidatesResponseDataHiringManagerReviewStatus.

        Email of the latest user who updated the review.  # noqa: E501

        :param reviewed_by_email: The reviewed_by_email of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :type: str
        """

        self._reviewed_by_email = reviewed_by_email

    @property
    def crm_manager_approval(self):
        """Gets the crm_manager_approval of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501

        Candidate's current status in relation to the job.  # noqa: E501

        :return: The crm_manager_approval of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :rtype: str
        """
        return self._crm_manager_approval

    @crm_manager_approval.setter
    def crm_manager_approval(self, crm_manager_approval):
        """Sets the crm_manager_approval of this GetCandidatesResponseDataHiringManagerReviewStatus.

        Candidate's current status in relation to the job.  # noqa: E501

        :param crm_manager_approval: The crm_manager_approval of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :type: str
        """

        self._crm_manager_approval = crm_manager_approval

    @property
    def reviewed_by_name(self):
        """Gets the reviewed_by_name of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501

        Name of the latest user who updated the review.  # noqa: E501

        :return: The reviewed_by_name of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :rtype: str
        """
        return self._reviewed_by_name

    @reviewed_by_name.setter
    def reviewed_by_name(self, reviewed_by_name):
        """Sets the reviewed_by_name of this GetCandidatesResponseDataHiringManagerReviewStatus.

        Name of the latest user who updated the review.  # noqa: E501

        :param reviewed_by_name: The reviewed_by_name of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :type: str
        """

        self._reviewed_by_name = reviewed_by_name

    @property
    def current_status(self):
        """Gets the current_status of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501

        Current hiring status of the candidate for this job.  # noqa: E501

        :return: The current_status of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :rtype: str
        """
        return self._current_status

    @current_status.setter
    def current_status(self, current_status):
        """Sets the current_status of this GetCandidatesResponseDataHiringManagerReviewStatus.

        Current hiring status of the candidate for this job.  # noqa: E501

        :param current_status: The current_status of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :type: str
        """

        self._current_status = current_status

    @property
    def manager_approval(self):
        """Gets the manager_approval of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501

        Indicates if the candidate is reviewed or in review pending by the candidate.  # noqa: E501

        :return: The manager_approval of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :rtype: str
        """
        return self._manager_approval

    @manager_approval.setter
    def manager_approval(self, manager_approval):
        """Sets the manager_approval of this GetCandidatesResponseDataHiringManagerReviewStatus.

        Indicates if the candidate is reviewed or in review pending by the candidate.  # noqa: E501

        :param manager_approval: The manager_approval of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :type: str
        """

        self._manager_approval = manager_approval

    @property
    def latest_manager_comment(self):
        """Gets the latest_manager_comment of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501

        Latest comment given by the hiring manager (encrypted).  # noqa: E501

        :return: The latest_manager_comment of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :rtype: str
        """
        return self._latest_manager_comment

    @latest_manager_comment.setter
    def latest_manager_comment(self, latest_manager_comment):
        """Sets the latest_manager_comment of this GetCandidatesResponseDataHiringManagerReviewStatus.

        Latest comment given by the hiring manager (encrypted).  # noqa: E501

        :param latest_manager_comment: The latest_manager_comment of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :type: str
        """

        self._latest_manager_comment = latest_manager_comment

    @property
    def comment(self):
        """Gets the comment of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501

        Comment provided on the candidate during the initial review.  # noqa: E501

        :return: The comment of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this GetCandidatesResponseDataHiringManagerReviewStatus.

        Comment provided on the candidate during the initial review.  # noqa: E501

        :param comment: The comment of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def updated_date(self):
        """Gets the updated_date of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501

        Latest updated date of the review.  # noqa: E501

        :return: The updated_date of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this GetCandidatesResponseDataHiringManagerReviewStatus.

        Latest updated date of the review.  # noqa: E501

        :param updated_date: The updated_date of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :type: str
        """

        self._updated_date = updated_date

    @property
    def previous_status(self):
        """Gets the previous_status of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501

        Previous status of the candidate in relation to the current status.  # noqa: E501

        :return: The previous_status of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :rtype: str
        """
        return self._previous_status

    @previous_status.setter
    def previous_status(self, previous_status):
        """Sets the previous_status of this GetCandidatesResponseDataHiringManagerReviewStatus.

        Previous status of the candidate in relation to the current status.  # noqa: E501

        :param previous_status: The previous_status of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :type: str
        """

        self._previous_status = previous_status

    @property
    def interview_overall_avg_rating(self):
        """Gets the interview_overall_avg_rating of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501

        Overall interview evaluations rating on the candidate with respect to the job.  # noqa: E501

        :return: The interview_overall_avg_rating of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :rtype: str
        """
        return self._interview_overall_avg_rating

    @interview_overall_avg_rating.setter
    def interview_overall_avg_rating(self, interview_overall_avg_rating):
        """Sets the interview_overall_avg_rating of this GetCandidatesResponseDataHiringManagerReviewStatus.

        Overall interview evaluations rating on the candidate with respect to the job.  # noqa: E501

        :param interview_overall_avg_rating: The interview_overall_avg_rating of this GetCandidatesResponseDataHiringManagerReviewStatus.  # noqa: E501
        :type: str
        """

        self._interview_overall_avg_rating = interview_overall_avg_rating

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetCandidatesResponseDataHiringManagerReviewStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCandidatesResponseDataHiringManagerReviewStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    communications-email

    These APIs ensures an easy integration process of email management for developers to send, read, and track email histories within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.communicationsemail.email_communications_api import EmailCommunicationsApi
from phenom.api.communicationsemail.forward_profile_api import ForwardProfileApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.communicationsemail.models.api_error import ApiError
from phenom.api.communicationsemail.models.api_link import ApiLink
from phenom.api.communicationsemail.models.bad_request import BadRequest
from phenom.api.communicationsemail.models.email_activity import EmailActivity
from phenom.api.communicationsemail.models.email_activity_data import EmailActivityData
from phenom.api.communicationsemail.models.email_history import EmailHistory
from phenom.api.communicationsemail.models.email_history_data import EmailHistoryData
from phenom.api.communicationsemail.models.email_history_pagination import EmailHistoryPagination
from phenom.api.communicationsemail.models.forward_profile_activity import ForwardProfileActivity
from phenom.api.communicationsemail.models.forward_profile_activity_data import ForwardProfileActivityData
from phenom.api.communicationsemail.models.forward_profile_activity_pagination import ForwardProfileActivityPagination
from phenom.api.communicationsemail.models.forward_profile_request import ForwardProfileRequest
from phenom.api.communicationsemail.models.forward_profile_response import ForwardProfileResponse
from phenom.api.communicationsemail.models.forward_profile_response_data import ForwardProfileResponseData
from phenom.api.communicationsemail.models.internal_server_error import InternalServerError
from phenom.api.communicationsemail.models.send_email_request import SendEmailRequest
from phenom.api.communicationsemail.models.send_email_response import SendEmailResponse
from phenom.api.communicationsemail.models.send_email_response_data import SendEmailResponseData
from phenom.api.communicationsemail.models.unauthorized_request import UnauthorizedRequest



# coding: utf-8

# flake8: noqa
"""
    communications-sms

    These APIs ensures an easy integration process of SMS management for developers to send, read, and track SMS histories within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.communicationssms.models.api_error import ApiError
from phenom.api.communicationssms.models.api_link import ApiLink
from phenom.api.communicationssms.models.bad_request import BadRequest
from phenom.api.communicationssms.models.internal_server_error import InternalServerError
from phenom.api.communicationssms.models.opt_in_history import OptInHistory
from phenom.api.communicationssms.models.opt_in_history_details import OptInHistoryDetails
from phenom.api.communicationssms.models.opt_in_history_details_content import OptInHistoryDetailsContent
from phenom.api.communicationssms.models.opt_in_history_details_pageable import OptInHistoryDetailsPageable
from phenom.api.communicationssms.models.opt_in_history_details_pageable_sort import OptInHistoryDetailsPageableSort
from phenom.api.communicationssms.models.opt_in_history_details_sort import OptInHistoryDetailsSort
from phenom.api.communicationssms.models.opt_in_request import OptInRequest
from phenom.api.communicationssms.models.opt_in_response import OptInResponse
from phenom.api.communicationssms.models.opt_in_response_details import OptInResponseDetails
from phenom.api.communicationssms.models.opt_in_status import OptInStatus
from phenom.api.communicationssms.models.opt_in_status_details import OptInStatusDetails
from phenom.api.communicationssms.models.sms_activity import SMSActivity
from phenom.api.communicationssms.models.sms_activity_data import SMSActivityData
from phenom.api.communicationssms.models.sms_history import SMSHistory
from phenom.api.communicationssms.models.sms_history_data import SMSHistoryData
from phenom.api.communicationssms.models.sms_history_pagination import SMSHistoryPagination
from phenom.api.communicationssms.models.send_sms import SendSMS
from phenom.api.communicationssms.models.send_sms_data import SendSMSData
from phenom.api.communicationssms.models.send_sms_request import SendSMSRequest
from phenom.api.communicationssms.models.unauthorized_request import UnauthorizedRequest



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetQuestionDetailsResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'question_id': 'str',
        'question_text': 'str',
        'type': 'str',
        'question_translations': 'list[GetQuestionDetailsResponseQuestionTranslations]',
        'options': 'object',
        'settings': 'GetQuestionDetailsResponseSettings',
        'date_created': 'int',
        'last_updated': 'int',
        'max_points': 'float'
    }

    attribute_map = {
        'question_id': 'questionId',
        'question_text': 'questionText',
        'type': 'type',
        'question_translations': 'questionTranslations',
        'options': 'options',
        'settings': 'settings',
        'date_created': 'dateCreated',
        'last_updated': 'lastUpdated',
        'max_points': 'maxPoints'
    }

    def __init__(self, question_id=None, question_text=None, type=None, question_translations=None, options=None, settings=None, date_created=None, last_updated=None, max_points=None):  # noqa: E501
        """GetQuestionDetailsResponseData - a model defined in Swagger"""  # noqa: E501
        self._question_id = None
        self._question_text = None
        self._type = None
        self._question_translations = None
        self._options = None
        self._settings = None
        self._date_created = None
        self._last_updated = None
        self._max_points = None
        self.discriminator = None
        self.question_id = question_id
        self.question_text = question_text
        self.type = type
        self.question_translations = question_translations
        self.options = options
        self.settings = settings
        self.date_created = date_created
        self.last_updated = last_updated
        self.max_points = max_points

    @property
    def question_id(self):
        """Gets the question_id of this GetQuestionDetailsResponseData.  # noqa: E501

        Question id of the question.  # noqa: E501

        :return: The question_id of this GetQuestionDetailsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._question_id

    @question_id.setter
    def question_id(self, question_id):
        """Sets the question_id of this GetQuestionDetailsResponseData.

        Question id of the question.  # noqa: E501

        :param question_id: The question_id of this GetQuestionDetailsResponseData.  # noqa: E501
        :type: str
        """
        if question_id is None:
            raise ValueError("Invalid value for `question_id`, must not be `None`")  # noqa: E501

        self._question_id = question_id

    @property
    def question_text(self):
        """Gets the question_text of this GetQuestionDetailsResponseData.  # noqa: E501

        Question text for a question.  # noqa: E501

        :return: The question_text of this GetQuestionDetailsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._question_text

    @question_text.setter
    def question_text(self, question_text):
        """Sets the question_text of this GetQuestionDetailsResponseData.

        Question text for a question.  # noqa: E501

        :param question_text: The question_text of this GetQuestionDetailsResponseData.  # noqa: E501
        :type: str
        """
        if question_text is None:
            raise ValueError("Invalid value for `question_text`, must not be `None`")  # noqa: E501

        self._question_text = question_text

    @property
    def type(self):
        """Gets the type of this GetQuestionDetailsResponseData.  # noqa: E501

        Type of the question, could be video, audio, videoOrAudio, multiple, scored, single, knockout, text.  # noqa: E501

        :return: The type of this GetQuestionDetailsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GetQuestionDetailsResponseData.

        Type of the question, could be video, audio, videoOrAudio, multiple, scored, single, knockout, text.  # noqa: E501

        :param type: The type of this GetQuestionDetailsResponseData.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def question_translations(self):
        """Gets the question_translations of this GetQuestionDetailsResponseData.  # noqa: E501

        Questions translated for a locale.  # noqa: E501

        :return: The question_translations of this GetQuestionDetailsResponseData.  # noqa: E501
        :rtype: list[GetQuestionDetailsResponseQuestionTranslations]
        """
        return self._question_translations

    @question_translations.setter
    def question_translations(self, question_translations):
        """Sets the question_translations of this GetQuestionDetailsResponseData.

        Questions translated for a locale.  # noqa: E501

        :param question_translations: The question_translations of this GetQuestionDetailsResponseData.  # noqa: E501
        :type: list[GetQuestionDetailsResponseQuestionTranslations]
        """
        if question_translations is None:
            raise ValueError("Invalid value for `question_translations`, must not be `None`")  # noqa: E501

        self._question_translations = question_translations

    @property
    def options(self):
        """Gets the options of this GetQuestionDetailsResponseData.  # noqa: E501

        In this options object, send the locale specific option ids(this is applicable only for single,scored,multiple,knockout questions).  # noqa: E501

        :return: The options of this GetQuestionDetailsResponseData.  # noqa: E501
        :rtype: object
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this GetQuestionDetailsResponseData.

        In this options object, send the locale specific option ids(this is applicable only for single,scored,multiple,knockout questions).  # noqa: E501

        :param options: The options of this GetQuestionDetailsResponseData.  # noqa: E501
        :type: object
        """
        if options is None:
            raise ValueError("Invalid value for `options`, must not be `None`")  # noqa: E501

        self._options = options

    @property
    def settings(self):
        """Gets the settings of this GetQuestionDetailsResponseData.  # noqa: E501


        :return: The settings of this GetQuestionDetailsResponseData.  # noqa: E501
        :rtype: GetQuestionDetailsResponseSettings
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this GetQuestionDetailsResponseData.


        :param settings: The settings of this GetQuestionDetailsResponseData.  # noqa: E501
        :type: GetQuestionDetailsResponseSettings
        """
        if settings is None:
            raise ValueError("Invalid value for `settings`, must not be `None`")  # noqa: E501

        self._settings = settings

    @property
    def date_created(self):
        """Gets the date_created of this GetQuestionDetailsResponseData.  # noqa: E501

        Date when the question is created.  # noqa: E501

        :return: The date_created of this GetQuestionDetailsResponseData.  # noqa: E501
        :rtype: int
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this GetQuestionDetailsResponseData.

        Date when the question is created.  # noqa: E501

        :param date_created: The date_created of this GetQuestionDetailsResponseData.  # noqa: E501
        :type: int
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def last_updated(self):
        """Gets the last_updated of this GetQuestionDetailsResponseData.  # noqa: E501

        Date when the question is updated.  # noqa: E501

        :return: The last_updated of this GetQuestionDetailsResponseData.  # noqa: E501
        :rtype: int
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this GetQuestionDetailsResponseData.

        Date when the question is updated.  # noqa: E501

        :param last_updated: The last_updated of this GetQuestionDetailsResponseData.  # noqa: E501
        :type: int
        """
        if last_updated is None:
            raise ValueError("Invalid value for `last_updated`, must not be `None`")  # noqa: E501

        self._last_updated = last_updated

    @property
    def max_points(self):
        """Gets the max_points of this GetQuestionDetailsResponseData.  # noqa: E501

        This is applicable for the scored question only.  # noqa: E501

        :return: The max_points of this GetQuestionDetailsResponseData.  # noqa: E501
        :rtype: float
        """
        return self._max_points

    @max_points.setter
    def max_points(self, max_points):
        """Sets the max_points of this GetQuestionDetailsResponseData.

        This is applicable for the scored question only.  # noqa: E501

        :param max_points: The max_points of this GetQuestionDetailsResponseData.  # noqa: E501
        :type: float
        """
        if max_points is None:
            raise ValueError("Invalid value for `max_points`, must not be `None`")  # noqa: E501

        self._max_points = max_points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetQuestionDetailsResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetQuestionDetailsResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobsListResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'size': 'float',
        '_from': 'float',
        'total_count': 'float',
        'jobs': 'list[JobDetails]'
    }

    attribute_map = {
        'size': 'size',
        '_from': 'from',
        'total_count': 'totalCount',
        'jobs': 'jobs'
    }

    def __init__(self, size=None, _from=None, total_count=None, jobs=None):  # noqa: E501
        """JobsListResponseData - a model defined in Swagger"""  # noqa: E501
        self._size = None
        self.__from = None
        self._total_count = None
        self._jobs = None
        self.discriminator = None
        if size is not None:
            self.size = size
        if _from is not None:
            self._from = _from
        if total_count is not None:
            self.total_count = total_count
        if jobs is not None:
            self.jobs = jobs

    @property
    def size(self):
        """Gets the size of this JobsListResponseData.  # noqa: E501

        Number of records to return.  # noqa: E501

        :return: The size of this JobsListResponseData.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this JobsListResponseData.

        Number of records to return.  # noqa: E501

        :param size: The size of this JobsListResponseData.  # noqa: E501
        :type: float
        """

        self._size = size

    @property
    def _from(self):
        """Gets the _from of this JobsListResponseData.  # noqa: E501

        Number to fetch records from.  # noqa: E501

        :return: The _from of this JobsListResponseData.  # noqa: E501
        :rtype: float
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this JobsListResponseData.

        Number to fetch records from.  # noqa: E501

        :param _from: The _from of this JobsListResponseData.  # noqa: E501
        :type: float
        """

        self.__from = _from

    @property
    def total_count(self):
        """Gets the total_count of this JobsListResponseData.  # noqa: E501

        Total number of records satisfying this request.  # noqa: E501

        :return: The total_count of this JobsListResponseData.  # noqa: E501
        :rtype: float
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this JobsListResponseData.

        Total number of records satisfying this request.  # noqa: E501

        :param total_count: The total_count of this JobsListResponseData.  # noqa: E501
        :type: float
        """

        self._total_count = total_count

    @property
    def jobs(self):
        """Gets the jobs of this JobsListResponseData.  # noqa: E501


        :return: The jobs of this JobsListResponseData.  # noqa: E501
        :rtype: list[JobDetails]
        """
        return self._jobs

    @jobs.setter
    def jobs(self, jobs):
        """Sets the jobs of this JobsListResponseData.


        :param jobs: The jobs of this JobsListResponseData.  # noqa: E501
        :type: list[JobDetails]
        """

        self._jobs = jobs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobsListResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobsListResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    prediction-api

    An API that predicts skills based on job titles and provided skill sets.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class SkillPredictionRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'titles': 'list[str]',
        'skills': 'list[str]',
        'size': 'int',
        'source': 'str'
    }

    attribute_map = {
        'titles': 'titles',
        'skills': 'skills',
        'size': 'size',
        'source': 'source'
    }

    def __init__(self, titles=None, skills=None, size=10, source=None):  # noqa: E501
        """SkillPredictionRequest - a model defined in Swagger"""  # noqa: E501
        self._titles = None
        self._skills = None
        self._size = None
        self._source = None
        self.discriminator = None
        if titles is not None:
            self.titles = titles
        if skills is not None:
            self.skills = skills
        if size is not None:
            self.size = size
        if source is not None:
            self.source = source

    @property
    def titles(self):
        """Gets the titles of this SkillPredictionRequest.  # noqa: E501

        Titles' List.  # noqa: E501

        :return: The titles of this SkillPredictionRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._titles

    @titles.setter
    def titles(self, titles):
        """Sets the titles of this SkillPredictionRequest.

        Titles' List.  # noqa: E501

        :param titles: The titles of this SkillPredictionRequest.  # noqa: E501
        :type: list[str]
        """

        self._titles = titles

    @property
    def skills(self):
        """Gets the skills of this SkillPredictionRequest.  # noqa: E501

        Skills' List.  # noqa: E501

        :return: The skills of this SkillPredictionRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._skills

    @skills.setter
    def skills(self, skills):
        """Sets the skills of this SkillPredictionRequest.

        Skills' List.  # noqa: E501

        :param skills: The skills of this SkillPredictionRequest.  # noqa: E501
        :type: list[str]
        """

        self._skills = skills

    @property
    def size(self):
        """Gets the size of this SkillPredictionRequest.  # noqa: E501

        Size of skills to return.  # noqa: E501

        :return: The size of this SkillPredictionRequest.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this SkillPredictionRequest.

        Size of skills to return.  # noqa: E501

        :param size: The size of this SkillPredictionRequest.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def source(self):
        """Gets the source of this SkillPredictionRequest.  # noqa: E501

        Source.  # noqa: E501

        :return: The source of this SkillPredictionRequest.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this SkillPredictionRequest.

        Source.  # noqa: E501

        :param source: The source of this SkillPredictionRequest.  # noqa: E501
        :type: str
        """

        self._source = source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SkillPredictionRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SkillPredictionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class ApplicantsApi(object):
    base_path = "/candidates-api/applications"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def get_applicants_for_job(self, job_id, x_ph_userid, _from, size, **kwargs):  # noqa: E501
        """Get Applicants  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_applicants_for_job(job_id, x_ph_userid, _from, size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: (required)
        :param str x_ph_userid: (required)
        :param int _from: (required)
        :param int size: (required)
        :return: Applicants
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_applicants_for_job_with_http_info(job_id, x_ph_userid, _from, size, **kwargs)  # noqa: E501
        else:
            (data) = self.get_applicants_for_job_with_http_info(job_id, x_ph_userid, _from, size, **kwargs)  # noqa: E501
            return data

    def get_applicants_for_job_with_http_info(self, job_id, x_ph_userid, _from, size, **kwargs):  # noqa: E501
        """Get Applicants  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_applicants_for_job_with_http_info(job_id, x_ph_userid, _from, size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: (required)
        :param str x_ph_userid: (required)
        :param int _from: (required)
        :param int size: (required)
        :return: Applicants
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id', 'x_ph_userid', '_from', 'size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_applicants_for_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `get_applicants_for_job`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `get_applicants_for_job`")  # noqa: E501
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `get_applicants_for_job`")  # noqa: E501
        # verify the required parameter 'size' is set
        if ('size' not in params or
                params['size'] is None):
            raise ValueError("Missing the required parameter `size` when calling `get_applicants_for_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']  # noqa: E501

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'size' in params:
            query_params.append(('size', params['size']))  # noqa: E501

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/jobs/{jobId}/applicants', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Applicants',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_candidate_applications(self, x_ph_userid, candidate_id, **kwargs):  # noqa: E501
        """Get Candidate Applications  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_applications(x_ph_userid, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_userid: (required)
        :param str candidate_id: ID of the candidate. (Required) (required)
        :return: CandidateApplications
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_candidate_applications_with_http_info(x_ph_userid, candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_candidate_applications_with_http_info(x_ph_userid, candidate_id, **kwargs)  # noqa: E501
            return data

    def get_candidate_applications_with_http_info(self, x_ph_userid, candidate_id, **kwargs):  # noqa: E501
        """Get Candidate Applications  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_applications_with_http_info(x_ph_userid, candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_userid: (required)
        :param str candidate_id: ID of the candidate. (Required) (required)
        :return: CandidateApplications
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_ph_userid', 'candidate_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_candidate_applications" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `get_candidate_applications`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_candidate_applications`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/applications', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CandidateApplications',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_job_specific_additional_fields(self, x_ph_userid, candidate_id, job_id, **kwargs):  # noqa: E501
        """Get Additional Fields  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_job_specific_additional_fields(x_ph_userid, candidate_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_userid: (required)
        :param str candidate_id: ID of the candidate. (Required) (required)
        :param str job_id: ID of the job. (Required) (required)
        :return: AdditionalFields
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_job_specific_additional_fields_with_http_info(x_ph_userid, candidate_id, job_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_job_specific_additional_fields_with_http_info(x_ph_userid, candidate_id, job_id, **kwargs)  # noqa: E501
            return data

    def get_job_specific_additional_fields_with_http_info(self, x_ph_userid, candidate_id, job_id, **kwargs):  # noqa: E501
        """Get Additional Fields  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_job_specific_additional_fields_with_http_info(x_ph_userid, candidate_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_userid: (required)
        :param str candidate_id: ID of the candidate. (Required) (required)
        :param str job_id: ID of the job. (Required) (required)
        :return: AdditionalFields
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_ph_userid', 'candidate_id', 'job_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_job_specific_additional_fields" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `get_job_specific_additional_fields`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_job_specific_additional_fields`")  # noqa: E501
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `get_job_specific_additional_fields`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/jobs/{jobId}/additional-fields', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AdditionalFields',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_job_specific_additional_fields(self, body, x_ph_userid, candidate_id, job_id, **kwargs):  # noqa: E501
        """Update Additional Fields  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_job_specific_additional_fields(body, x_ph_userid, candidate_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AdditionalFieldsUpdateRequest body: update job specific additional fields of a candidate (required)
        :param str x_ph_userid: (required)
        :param str candidate_id: ID of the candidate. (Required) (required)
        :param str job_id: ID of the job. (Required) (required)
        :return: AdditionalFieldsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_job_specific_additional_fields_with_http_info(body, x_ph_userid, candidate_id, job_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_job_specific_additional_fields_with_http_info(body, x_ph_userid, candidate_id, job_id, **kwargs)  # noqa: E501
            return data

    def update_job_specific_additional_fields_with_http_info(self, body, x_ph_userid, candidate_id, job_id, **kwargs):  # noqa: E501
        """Update Additional Fields  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_job_specific_additional_fields_with_http_info(body, x_ph_userid, candidate_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AdditionalFieldsUpdateRequest body: update job specific additional fields of a candidate (required)
        :param str x_ph_userid: (required)
        :param str candidate_id: ID of the candidate. (Required) (required)
        :param str job_id: ID of the job. (Required) (required)
        :return: AdditionalFieldsUpdateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_userid', 'candidate_id', 'job_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_job_specific_additional_fields" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_job_specific_additional_fields`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `update_job_specific_additional_fields`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `update_job_specific_additional_fields`")  # noqa: E501
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `update_job_specific_additional_fields`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/jobs/{jobId}/additional-fields', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AdditionalFieldsUpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class ApplicationsApi(object):
    base_path = "/apply"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def check_if_already_applied(self, email, job_id, locale, **kwargs):  # noqa: E501
        """Check Already Applied  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.check_if_already_applied(email, job_id, locale, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: Email Address. (required)
        :param str job_id: Job Id of the job for which the applicant is applying. (required)
        :param str locale: Corresponding locale of the job that the candidate is applying/applied. (required)
        :param str site_type: Persona of the Job.
        :return: AlreadyAppliedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.check_if_already_applied_with_http_info(email, job_id, locale, **kwargs)  # noqa: E501
        else:
            (data) = self.check_if_already_applied_with_http_info(email, job_id, locale, **kwargs)  # noqa: E501
            return data

    def check_if_already_applied_with_http_info(self, email, job_id, locale, **kwargs):  # noqa: E501
        """Check Already Applied  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.check_if_already_applied_with_http_info(email, job_id, locale, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: Email Address. (required)
        :param str job_id: Job Id of the job for which the applicant is applying. (required)
        :param str locale: Corresponding locale of the job that the candidate is applying/applied. (required)
        :param str site_type: Persona of the Job.
        :return: AlreadyAppliedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['email', 'job_id', 'locale', 'site_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method check_if_already_applied" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'email' is set
        if ('email' not in params or
                params['email'] is None):
            raise ValueError("Missing the required parameter `email` when calling `check_if_already_applied`")  # noqa: E501
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `check_if_already_applied`")  # noqa: E501
        # verify the required parameter 'locale' is set
        if ('locale' not in params or
                params['locale'] is None):
            raise ValueError("Missing the required parameter `locale` when calling `check_if_already_applied`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'email' in params:
            header_params['email'] = params['email']  # noqa: E501
        if 'job_id' in params:
            header_params['jobId'] = params['job_id']  # noqa: E501
        if 'site_type' in params:
            header_params['siteType'] = params['site_type']  # noqa: E501
        if 'locale' in params:
            header_params['locale'] = params['locale']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/applications/status', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AlreadyAppliedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_application(self, id, **kwargs):  # noqa: E501
        """Get Application by ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_application(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: It is a 24-digit hexadecimal value that represents Application Id. (required)
        :return: GetApplicationByIdResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_application_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_application_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_application_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get Application by ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_application_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: It is a 24-digit hexadecimal value that represents Application Id. (required)
        :return: GetApplicationByIdResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_application" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_application`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/applications/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetApplicationByIdResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_applications(self, **kwargs):  # noqa: E501
        """Get Applications  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_applications(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The number of items to offset from the result set.
        :param int limit: The number of items to return.
        :return: GetApplicationsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_applications_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_applications_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_applications_with_http_info(self, **kwargs):  # noqa: E501
        """Get Applications  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_applications_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The number of items to offset from the result set.
        :param int limit: The number of items to return.
        :return: GetApplicationsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_applications" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/applications', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetApplicationsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def submit_application(self, body, locale, **kwargs):  # noqa: E501
        """Submit Application  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submit_application(body, locale, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApplicationWithResume body: (required)
        :param str locale: Corresponding locale of the job that the candidate is applying/applied. (required)
        :param str site_type: Persona of the Job.
        :return: SubmitApplicationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.submit_application_with_http_info(body, locale, **kwargs)  # noqa: E501
        else:
            (data) = self.submit_application_with_http_info(body, locale, **kwargs)  # noqa: E501
            return data

    def submit_application_with_http_info(self, body, locale, **kwargs):  # noqa: E501
        """Submit Application  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submit_application_with_http_info(body, locale, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApplicationWithResume body: (required)
        :param str locale: Corresponding locale of the job that the candidate is applying/applied. (required)
        :param str site_type: Persona of the Job.
        :return: SubmitApplicationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'locale', 'site_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submit_application" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `submit_application`")  # noqa: E501
        # verify the required parameter 'locale' is set
        if ('locale' not in params or
                params['locale'] is None):
            raise ValueError("Missing the required parameter `locale` when calling `submit_application`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'site_type' in params:
            header_params['siteType'] = params['site_type']  # noqa: E501
        if 'locale' in params:
            header_params['locale'] = params['locale']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/applications', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubmitApplicationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def submit_application_v1(self, body, **kwargs):  # noqa: E501
        """Submit Application  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submit_application_v1(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApplicationWithResume body: (required)
        :return: SuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.submit_application_v1_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.submit_application_v1_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def submit_application_v1_with_http_info(self, body, **kwargs):  # noqa: E501
        """Submit Application  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submit_application_v1_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ApplicationWithResume body: (required)
        :return: SuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submit_application_v1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `submit_application_v1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/applications', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class Pagination(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'offset': 'int',
        'limit': 'int',
        'total': 'int'
    }

    attribute_map = {
        'offset': 'offset',
        'limit': 'limit',
        'total': 'total'
    }

    def __init__(self, offset=None, limit=None, total=None):  # noqa: E501
        """Pagination - a model defined in Swagger"""  # noqa: E501
        self._offset = None
        self._limit = None
        self._total = None
        self.discriminator = None
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if total is not None:
            self.total = total

    @property
    def offset(self):
        """Gets the offset of this Pagination.  # noqa: E501

        The number of items to offset from the result set.  # noqa: E501

        :return: The offset of this Pagination.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this Pagination.

        The number of items to offset from the result set.  # noqa: E501

        :param offset: The offset of this Pagination.  # noqa: E501
        :type: int
        """

        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this Pagination.  # noqa: E501

        The number of items to return.  # noqa: E501

        :return: The limit of this Pagination.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this Pagination.

        The number of items to return.  # noqa: E501

        :param limit: The limit of this Pagination.  # noqa: E501
        :type: int
        """

        self._limit = limit

    @property
    def total(self):
        """Gets the total of this Pagination.  # noqa: E501

        The total number of items in the result set.  # noqa: E501

        :return: The total of this Pagination.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this Pagination.

        The total number of items in the result set.  # noqa: E501

        :param total: The total of this Pagination.  # noqa: E501
        :type: int
        """

        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Pagination, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Pagination):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EnableOneWayInterviewResponseDataAutoReminderData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auto_reminder_enabled': 'bool',
        'value': 'float',
        'unit': 'str',
        'template_identifier': 'str'
    }

    attribute_map = {
        'auto_reminder_enabled': 'autoReminderEnabled',
        'value': 'value',
        'unit': 'unit',
        'template_identifier': 'templateIdentifier'
    }

    def __init__(self, auto_reminder_enabled=None, value=None, unit=None, template_identifier=None):  # noqa: E501
        """EnableOneWayInterviewResponseDataAutoReminderData - a model defined in Swagger"""  # noqa: E501
        self._auto_reminder_enabled = None
        self._value = None
        self._unit = None
        self._template_identifier = None
        self.discriminator = None
        self.auto_reminder_enabled = auto_reminder_enabled
        self.value = value
        self.unit = unit
        self.template_identifier = template_identifier

    @property
    def auto_reminder_enabled(self):
        """Gets the auto_reminder_enabled of this EnableOneWayInterviewResponseDataAutoReminderData.  # noqa: E501

        true if auto reminder is enabled else false.  # noqa: E501

        :return: The auto_reminder_enabled of this EnableOneWayInterviewResponseDataAutoReminderData.  # noqa: E501
        :rtype: bool
        """
        return self._auto_reminder_enabled

    @auto_reminder_enabled.setter
    def auto_reminder_enabled(self, auto_reminder_enabled):
        """Sets the auto_reminder_enabled of this EnableOneWayInterviewResponseDataAutoReminderData.

        true if auto reminder is enabled else false.  # noqa: E501

        :param auto_reminder_enabled: The auto_reminder_enabled of this EnableOneWayInterviewResponseDataAutoReminderData.  # noqa: E501
        :type: bool
        """
        if auto_reminder_enabled is None:
            raise ValueError("Invalid value for `auto_reminder_enabled`, must not be `None`")  # noqa: E501

        self._auto_reminder_enabled = auto_reminder_enabled

    @property
    def value(self):
        """Gets the value of this EnableOneWayInterviewResponseDataAutoReminderData.  # noqa: E501

        Number of days before expiry to send the reminder.  # noqa: E501

        :return: The value of this EnableOneWayInterviewResponseDataAutoReminderData.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this EnableOneWayInterviewResponseDataAutoReminderData.

        Number of days before expiry to send the reminder.  # noqa: E501

        :param value: The value of this EnableOneWayInterviewResponseDataAutoReminderData.  # noqa: E501
        :type: float
        """
        if value is None:
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def unit(self):
        """Gets the unit of this EnableOneWayInterviewResponseDataAutoReminderData.  # noqa: E501

        Indicates the value is days.  # noqa: E501

        :return: The unit of this EnableOneWayInterviewResponseDataAutoReminderData.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this EnableOneWayInterviewResponseDataAutoReminderData.

        Indicates the value is days.  # noqa: E501

        :param unit: The unit of this EnableOneWayInterviewResponseDataAutoReminderData.  # noqa: E501
        :type: str
        """
        if unit is None:
            raise ValueError("Invalid value for `unit`, must not be `None`")  # noqa: E501

        self._unit = unit

    @property
    def template_identifier(self):
        """Gets the template_identifier of this EnableOneWayInterviewResponseDataAutoReminderData.  # noqa: E501

        Email template identifier.  # noqa: E501

        :return: The template_identifier of this EnableOneWayInterviewResponseDataAutoReminderData.  # noqa: E501
        :rtype: str
        """
        return self._template_identifier

    @template_identifier.setter
    def template_identifier(self, template_identifier):
        """Sets the template_identifier of this EnableOneWayInterviewResponseDataAutoReminderData.

        Email template identifier.  # noqa: E501

        :param template_identifier: The template_identifier of this EnableOneWayInterviewResponseDataAutoReminderData.  # noqa: E501
        :type: str
        """
        if template_identifier is None:
            raise ValueError("Invalid value for `template_identifier`, must not be `None`")  # noqa: E501

        self._template_identifier = template_identifier

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EnableOneWayInterviewResponseDataAutoReminderData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnableOneWayInterviewResponseDataAutoReminderData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    jobs-questionnarie-api

    These APIs streamline question management, providing tools to create, delete, and update questions. Additionally, they offer functionality to attach question lists to specific job profiles.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class QuestionnaireTemplatesApi(object):
    base_path = "/jobs-api/questionnarie"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def create_questionnarie_template(self, body, x_ph_userid, **kwargs):  # noqa: E501
        """Create Questionnarie-Template  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_questionnarie_template(body, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateQuestionnarieTemplatesRequest body: Create QuestionnarieTemplates (required)
        :param str x_ph_userid: (required)
        :return: QuestionnarieTemplateCreationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_questionnarie_template_with_http_info(body, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.create_questionnarie_template_with_http_info(body, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def create_questionnarie_template_with_http_info(self, body, x_ph_userid, **kwargs):  # noqa: E501
        """Create Questionnarie-Template  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_questionnarie_template_with_http_info(body, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateQuestionnarieTemplatesRequest body: Create QuestionnarieTemplates (required)
        :param str x_ph_userid: (required)
        :return: QuestionnarieTemplateCreationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_userid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_questionnarie_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_questionnarie_template`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `create_questionnarie_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questionnarie-templates', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QuestionnarieTemplateCreationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_questionnarie_template(self, template_id, x_ph_userid, **kwargs):  # noqa: E501
        """Delete templates  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_questionnarie_template(template_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str template_id: templateId (required)
        :param str x_ph_userid: (required)
        :return: DeleteQuestionnarieTemplateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_questionnarie_template_with_http_info(template_id, x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_questionnarie_template_with_http_info(template_id, x_ph_userid, **kwargs)  # noqa: E501
            return data

    def delete_questionnarie_template_with_http_info(self, template_id, x_ph_userid, **kwargs):  # noqa: E501
        """Delete templates  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_questionnarie_template_with_http_info(template_id, x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str template_id: templateId (required)
        :param str x_ph_userid: (required)
        :return: DeleteQuestionnarieTemplateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['template_id', 'x_ph_userid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_questionnarie_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'template_id' is set
        if ('template_id' not in params or
                params['template_id'] is None):
            raise ValueError("Missing the required parameter `template_id` when calling `delete_questionnarie_template`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `delete_questionnarie_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'template_id' in params:
            path_params['templateId'] = params['template_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questionnarie-templates/{templateId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteQuestionnarieTemplateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_job_questionnarie(self, x_ph_userid, **kwargs):  # noqa: E501
        """Fetch templetes.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_job_questionnarie(x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_userid: (required)
        :param int _from: The number of questionnarie-templates to skip before starting to collect the result.
        :param int size: count of the questionnarie templates to be returned in response.
        :param str search_key: keyword to search
        :return: GetQuestionnarieTemplatesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_job_questionnarie_with_http_info(x_ph_userid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_job_questionnarie_with_http_info(x_ph_userid, **kwargs)  # noqa: E501
            return data

    def get_job_questionnarie_with_http_info(self, x_ph_userid, **kwargs):  # noqa: E501
        """Fetch templetes.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_job_questionnarie_with_http_info(x_ph_userid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_userid: (required)
        :param int _from: The number of questionnarie-templates to skip before starting to collect the result.
        :param int size: count of the questionnarie templates to be returned in response.
        :param str search_key: keyword to search
        :return: GetQuestionnarieTemplatesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_ph_userid', '_from', 'size', 'search_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_job_questionnarie" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `get_job_questionnarie`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'size' in params:
            query_params.append(('size', params['size']))  # noqa: E501
        if 'search_key' in params:
            query_params.append(('searchKey', params['search_key']))  # noqa: E501

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questionnarie-templates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetQuestionnarieTemplatesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_questionnarie_template(self, body, x_ph_userid, template_id, **kwargs):  # noqa: E501
        """Update Template  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_questionnarie_template(body, x_ph_userid, template_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateQuestionnaireTemplateRequest body: update questionnaire template. (required)
        :param str x_ph_userid: (required)
        :param str template_id: templateId (required)
        :return: UpdateTemplateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_questionnarie_template_with_http_info(body, x_ph_userid, template_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_questionnarie_template_with_http_info(body, x_ph_userid, template_id, **kwargs)  # noqa: E501
            return data

    def update_questionnarie_template_with_http_info(self, body, x_ph_userid, template_id, **kwargs):  # noqa: E501
        """Update Template  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_questionnarie_template_with_http_info(body, x_ph_userid, template_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateQuestionnaireTemplateRequest body: update questionnaire template. (required)
        :param str x_ph_userid: (required)
        :param str template_id: templateId (required)
        :return: UpdateTemplateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_ph_userid', 'template_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_questionnarie_template" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_questionnarie_template`")  # noqa: E501
        # verify the required parameter 'x_ph_userid' is set
        if ('x_ph_userid' not in params or
                params['x_ph_userid'] is None):
            raise ValueError("Missing the required parameter `x_ph_userid` when calling `update_questionnarie_template`")  # noqa: E501
        # verify the required parameter 'template_id' is set
        if ('template_id' not in params or
                params['template_id'] is None):
            raise ValueError("Missing the required parameter `template_id` when calling `update_questionnarie_template`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'template_id' in params:
            path_params['templateId'] = params['template_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_userid' in params:
            header_params['x-ph-userid'] = params['x_ph_userid']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questionnarie-templates/{templateId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateTemplateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
